using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Character2D : MonoBehaviour
{
    [SerializeField] protected float movementSpeed = 0f; // How fast the character moves
    [SerializeField] protected float firingDelay = 1f; // How long to wait between shots
    
    [SerializeField] protected Color color1 = Color.red;
    [SerializeField] protected Color color2 = Color.blue;
    protected bool isColor1 = true;
    
    [SerializeField] protected string projectilePath = ""; // Needed to load in projectile
    protected bool charCanFire = true; // Required for shooting
    
    protected Rigidbody2D body = null;
    
    // -----------------
    // MISC FUNCTIONS
    // -----------------
    
    // Gets the character's rigidbody
    protected void GetRigidbody()
    {
        body = this.GetComponent<Rigidbody2D>();
    }

    // -----------------
    // MOVEMENT FUNCTIONS
    // -----------------
    
    // Moves the character to a target position
    // protected virtual IEnumerator Move (Vector2 position) {yield return null;}
    protected virtual void Move (Vector2 direction) 
    {
        body.AddForce(direction.normalized * Time.deltaTime * movementSpeed);
    }
    
    // -----------------
    // SHOOTING FUNCTIONS
    // -----------------
    
    // Used to control firing process
    protected virtual IEnumerator FireProjectile () {yield return null;}
    
    // Spawns a projectile
    protected virtual void SpawnProjectile (string projectilePath, Vector2 spawnPoint) {return;}
    
    // -----------------
    // COLOR FUNCTIONS
    // -----------------
    
    // Changes the character's color
    protected void ChangeCharacterColor(Color color)
    {
        this.GetComponent<SpriteRenderer>().color = color;
    }
    
    // Randomizes the character's color
    protected void RandomizeColor()
    {
        int rand = Random.Range(0, 2);
        if (rand == 0) ChangeCharacterColor(color1);
        else ChangeCharacterColor(color2);
        isColor1 = (rand == 0);
    }
    
    // Checks the character's color
    public bool CheckCharacterColor()
    {
        return isColor1 == true;
    }
    
}
