using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Enemy2D : Character2D
{
    protected float maxHeight = 100f; // Screen height. Needed to spawn enemies off-screen
    protected float maxWidth = 100f; // Screen width. Needed to spawn enemies off-screen
    [HideInInspector] public int enemyID = 0; // Each enemy type receives its own ID number
    
    [SerializeField] private float offset = 10f; // For minor spawn adjustments
      
    public void OnTriggerEnter2D (Collider2D other)
    {
        if (other.gameObject.tag == "Player")
        {
            StartCoroutine(other.gameObject.GetComponent<Player2D>().KillPlayer());
        }
    }        
    
    // Changes the enemy's speed
    public void AdjustSpeed(float diff)
    {
        movementSpeed += diff;
    }
    
    // Sets the enemy's spawn point
    protected virtual void SetSpawnPoint()
    {
        float xPoint = 0f;
        float yPoint = 0f;
        if (Random.Range(0, 2) == 1) // x-coordinate is randomized
        {
            if (Random.Range(0, 2) == 0) yPoint = -maxHeight;
            else yPoint = maxHeight;
            xPoint = Random.Range(-maxWidth, maxWidth);
        }
        else // y-coordinate is randomized
        {
            if (Random.Range(0, 2) == 0) xPoint = -maxWidth;
            else xPoint = maxWidth;
            yPoint = Random.Range(-maxHeight, maxHeight);
        }
        this.transform.position = new Vector2(xPoint, yPoint);
    }
    
    // Finds the spawn boundaries so enemies spawn off-screen
    protected void FindSpawnBoundaries()
    {
        maxHeight = Camera.main.orthographicSize * 2f;
        maxWidth = maxHeight * Screen.width / Screen.height;
    }
}
