using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class FiringEnemy : Enemy2D
{
    private Vector2[] bulletDirections = new Vector2[] {Vector2.up, Vector2.down, Vector2.left, Vector2.right};
    
    private void Awake()
    {
        enemyID = 2;
        charCanFire = true;
        GetRigidbody();
        FindSpawnBoundaries();
        SetSpawnPoint();
        RandomizeColor();
        Move(-this.transform.position);
    }
    
    private void Update()
    {
        if (EnemyInRangeOfCamera() && charCanFire) StartCoroutine(FireProjectile());
    }
    
    protected override IEnumerator FireProjectile()
    {
        charCanFire = false;
        SpawnProjectile("Prefabs/bullet", this.transform.position);
        yield return new WaitForSeconds(firingDelay);
        charCanFire = true;
    }
    
    protected override void SpawnProjectile (string projectilePath, Vector2 spawnPoint)
    {
        foreach (Vector2 direction in bulletDirections)
        {
            GameObject bullet = Instantiate(Resources.Load<GameObject>(projectilePath), spawnPoint, Quaternion.identity);
            bullet.GetComponent<Bullet>().SetProjectileColor(isColor1);
            bullet.GetComponent<Rigidbody2D>().velocity = body.velocity;
            bullet.GetComponent<Bullet>().SetDirection();
        }
    }
    
    private bool EnemyInRangeOfCamera()
    {
        float halfWidth = maxWidth / 2;
        float halfHeight = maxHeight / 2;
        return this.transform.position.x > -halfWidth && this.transform.position.x < halfWidth && this.transform.position.y > -halfHeight && this.transform.position.y < halfHeight;
    }
}
