using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

public class Player2D : Character2D
{
    private SpriteRenderer sprite = null; // Needed for fade-in fade-out animations
    
    private void Awake()
    {
        sprite = this.GetComponent<SpriteRenderer>();
        RandomizeColor();
        StartCoroutine(GameObject.FindGameObjectWithTag("TransitionScreen").GetComponent<TransitionScreen>().FadeTransition(Color.black, Color.clear));
    }
    
    private void Update()
    {
        if (Input.GetKeyDown(KeyCode.Space))
        {
            StartCoroutine(FireProjectile());
        }
        
        if (Input.GetKeyDown(KeyCode.C))
        {
            FlipColor();
        }
    }
    
    protected override IEnumerator FireProjectile () 
    {
        SpawnProjectile(projectilePath, this.transform.position);
        // FlipColor();
        yield return null;
    }
    
    // Spawns a projectile
    protected override void SpawnProjectile (string projectilePath, Vector2 spawnPoint)
    {
        GameObject projectile = Instantiate(Resources.Load<GameObject>(projectilePath), new Vector3(spawnPoint.x, spawnPoint.y, 0f), Quaternion.identity);
        projectile.GetComponent<Projectile>().SetProjectileColor(isColor1);
    }
    
    // Flips the character's color
    private void FlipColor()
    {
        if (isColor1) ChangeCharacterColor(color2);
        else ChangeCharacterColor(color1);
        isColor1 = !isColor1;
    }
    
    // Activates the game over sequence
    public IEnumerator KillPlayer()
    {
        sprite.color = Color.clear;
        yield return StartCoroutine(GameObject.FindGameObjectWithTag("TransitionScreen").GetComponent<TransitionScreen>().FadeTransition(Color.clear, Color.black));
        yield return GameObject.FindGameObjectWithTag("SceneTracker").GetComponent<SceneTracker>().OnSwitchToGameOverScreen();
        SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex + 1);
        yield return null;
    }
}
