using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ShrinkingEnemy : Enemy2D
{
    [SerializeField] private float animationDuration = 1f; // How long the shrinking animation lasts
    [SerializeField] private int health = 2; // How many hits the enemy can take
    
    private void Awake()
    {
        enemyID = 3;
        GetRigidbody();
        FindSpawnBoundaries();
        SetSpawnPoint();
        RandomizeColor();
        Move(-this.transform.position);
    }
    
    private void Update()
    {
        this.transform.Rotate(Vector3.forward * 10f * Time.deltaTime);
    }
    
    public bool EnemyCanBeDamaged()
    {
        health -= 1;
        return health > 0;
    }
    
    public void ShrinkEnemy()
    {
        if (health == 2) StartCoroutine(PlayShrinkAnimation(Vector3.one));
        else if (health == 1) StartCoroutine(PlayShrinkAnimation(Vector3.one * .5f));
    }
    
    public IEnumerator PlayShrinkAnimation(Vector3 targetScale)
    {
        float time = 0f;
        while (this.transform.localScale != targetScale || time < animationDuration)
        {
            this.transform.localScale = Vector3.Lerp(this.transform.localScale, targetScale, time / animationDuration);
            time += Time.deltaTime;
            yield return null;
        }
        this.transform.localScale = targetScale;
    }
}
