using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class EnemyManager2D : MonoBehaviour
{
    [SerializeField] private List<string> enemies; // List of enemies in the game
    [SerializeField] private int maxNumberOfEnemies = 10; // How many enemies can spawn on-screen
    [SerializeField] private float timeBetweenSpawns; // How long to wait between each spawn
    [SerializeField] private ScoreCounter scoreCounter = null; // Score counter --> Used to keep track of the player's score
    
    private int enemyCount = 0; // Number of enemies spawned on-screen
    private bool canSpawnEnemies = true;
    
    private float speedBoost = 0f; // Speed boost for enemy
    
    private void Start()
    {
        InvokeRepeating("IncreaseDifficulty", 5f, 5f);
    }
    
    private void Update ()
    {
        if (BelowEnemyCount() && canSpawnEnemies) StartCoroutine(SpawnEnemyWave());
    }
    
    // Creates a wave of enemies
    public IEnumerator SpawnEnemyWave()
    {
        canSpawnEnemies = false;
        if (BelowEnemyCount())
        {
            SpawnEnemy(enemies[Random.Range(0, enemies.Count)]);
            enemyCount++;
        }
        yield return new WaitForSeconds(timeBetweenSpawns);
        canSpawnEnemies = true;
    }
    
    // Loads an enemy
    public void SpawnEnemy(string pathToEnemy)
    {
        GameObject enemy = Instantiate(Resources.Load<GameObject>(pathToEnemy), Vector2.zero, Quaternion.identity);
        enemy.GetComponent<Enemy2D>().AdjustSpeed(speedBoost);
    }
    
    // Check whether we've spawned the max number of enemies
    private bool BelowEnemyCount()
    {
        return enemyCount < maxNumberOfEnemies;
    }
    
    // Removes an enemy from the current enemy count
    public void RegisterEnemyDeath(int ID)
    {
        if (ID == 1) scoreCounter.score += 6;
        else if (ID == 2) scoreCounter.score += 8;
        else scoreCounter.score += 4;
        
        enemyCount -= 1;
    }

    // Increase the difficulty of the game by adding faster enemies
    private void IncreaseDifficulty ()
    {
        if (speedBoost < 3000) speedBoost += 200f;
        if (maxNumberOfEnemies < 24) maxNumberOfEnemies += 1;
        if (timeBetweenSpawns > .3f) timeBetweenSpawns *= .9f;
        scoreCounter.IncreaseScoreSpeed();
    }
}
